@@ -24,6 +24,7 @@ import commander.commands.completion
 import commander.commands.result
 import commander.commands.exceptions
 
+from functools import reduce
 import re
 
 __commander_module__ = True
@@ -279,4 +280,4 @@ The regular expression will be matched in case-insensitive mode"""
 
     yield _regex(view, reg, align_group, padding, padding_group, re.IGNORECASE)
 
-# vi:ex:ts=4:et
+# ex:ts=4:et
