@@ -62,7 +62,7 @@ class Yandex(Service):
         return 'en|es'
 
     def get_api_hint(self):
-        return _("You need to obtain a free API key at <a href='https://tech.yandex.com/translate/'>https://tech.yandex.com/translate/</a>")
+        return _("You need to obtain an API key at <a href='https://yandex.com/dev/translate/'>https://yandex.com/dev/translate/</a>")
 
     def has_api_key(self):
         return True
@@ -70,6 +70,9 @@ class Yandex(Service):
     def set_api_key(self, key):
         self._key = key
 
+    def set_server(self, server):
+        pass
+
     def init(self):
         self._fetch_remote_language_names()
 
